                                                                  /*
Copyright (c) 2012, Parallel Universe, Inc. All rights reserved.
Patent Pending, Application Filed on May 3, 2012.
							          */


/* Copyright (c) 2009 Sun Microsystems, Inc.
   Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifdef USE_REPRISE_LICENSE_MANAGER
#include "license.h"
#endif

#include "log.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "sql_select.h"

#ifndef _WIN32
#include <unistd.h>
#include <strings.h>
#endif /* _WIN32 */

/* 
  main() for mysqld.
  Calls mysqld_main() entry point exported by sql library.
*/
extern int mysqld_main(int argc, char **argv);

#ifdef USE_REPRISE_LICENSE_MANAGER
/******************************************************************************

	    COPYRIGHT (c) 2005, 2010 by Reprise Software, Inc.
	This software has been provided pursuant to a License Agreement
	containing restrictions on its use.  This software contains
	valuable trade secrets and proprietary information of 
	Reprise Software Inc and is protected by law.  It may not be 
	copied or distributed in any form or medium, disclosed to third 
	parties, reverse engineered or used in any manner not provided 
	for in said License Agreement except with the prior written 
	authorization from Reprise Software Inc.

 *****************************************************************************/
/*	
 *	Description: 	Test client for LM system
 *
 *	Usage:		% sampleclient [product [count [version]]]
 *
 *	Return:		None
 *
 *	M. Christiano
 *	11/27/05
 *
 *	$Id: sampleclient_nl.c,v 1.1 2010/01/20 08:27:19 matt Exp $
 */


static void printstat(RLM_HANDLE, RLM_LICENSE, const char *);

int
main(int argc, char *argv[])
{
  RLM_HANDLE rh;
  RLM_LICENSE lic = (RLM_LICENSE) NULL;
  int stat;
  char *options;
  char *product, p[RLM_MAX_PRODUCT+1];
  int count = 1; // # of licenses to check out
  // Parallel Universe server version
  const char *ver = "0.1";
  // Parallel Universe server directory
  const char *server_dir = "/usr/local/paralleluniverse-0.1/bin";

	rh = rlm_init(server_dir, argv[0], (char *) NULL);
	stat = rlm_stat(rh);
	if (stat)
	{
	  char errstring[RLM_ERRSTRING_MAX];

                fprintf(stderr, "Error initializing license system\n");
		fprintf(stderr, "%s\n", rlm_errstring((RLM_LICENSE) NULL, rh, 
								errstring));
	}
	else
	{

/*
 *		Use the program name as the license name
 */
		if      ((product = strrchr(argv[0], (int) '/')))  product++;
		else if ((product = strrchr(argv[0], (int) '\\'))) product++;
		else				  	   product = argv[0];
		strncpy(p, product, RLM_MAX_PRODUCT);
		p[RLM_MAX_PRODUCT] = '\0';
/* 
 *		Don't want .exe 
 */
		if ((product = strchr(p, '.'))) *product = '\0';	
		product = p;
/*
 *		If product name specified, override program name
 */
/*		if (argc > 1) product = argv[1];
		if (argc > 2) count = atoi(argv[2]);
		if (argc > 3) ver = argv[3]; */
		lic = rlm_checkout(rh, product, ver, count);
		printstat(rh, lic, product);
	}

        if (!stat) {
          stat= rlm_license_stat(lic);
          if (!stat) {
            options= rlm_license_options(lic);
            if (options && *options != 0) {
              max_no_parallel_tables= atoi(options);
              stat= mysqld_main(argc, argv);
	    } else {
              fprintf(stderr, "options missing from license file\n");
            }
          }
        }
	if (lic) 
	{
		rlm_checkin(lic);
		rlm_close(rh);
	}
	return(stat);
}

static
void
printstat(RLM_HANDLE rh, RLM_LICENSE lic, const char *name)
{
  int stat;
  char errstring[RLM_ERRSTRING_MAX];

	stat = rlm_license_stat(lic);
	if (stat == 0)
	  ;  //		fprintf(stderr, "Checkout of %s OK.\n", name);
	else
	{
		fprintf(stderr, "Error checking out %s license\n", name);
		fprintf(stderr, "%s\n", rlm_errstring(lic, rh, errstring));
	}
}
#else
// global variable, 0 implies unlimited
uint max_no_parallel_tables= MAXIMUM_NUMBER_OF_PARALLEL_TABLES;
// 1: Jan, 2: Feb
const int license_expiration_month= LICENSE_EXPIRATION_MONTH;
// LICENSE_EXPIRATION_YEAR in 4 digits as 2012
const int license_expiration_year= LICENSE_EXPIRATION_YEAR - 1900;

int
main(int argc, char *argv[])
{
  struct tm *tm_ptr;
  time_t lt;

  lt= time(0);
  tm_ptr= localtime(&lt);
  if (tm_ptr->tm_year > license_expiration_year ||
      (tm_ptr->tm_year == license_expiration_year &&
       tm_ptr->tm_mon >= license_expiration_month)) {
    //    return 0;
    ;
  }
  return mysqld_main(argc, argv);
}
#endif
